#[test]Expand description
Runs an async test function on an asupersync production runtime.
This is distinct from #[lab_test]: #[asupersync::test]
uses the production runtime, while #[lab_test] uses deterministic lab
runtime seed matrices.
#[test]Runs an async test function on an asupersync production runtime.
This is distinct from #[lab_test]: #[asupersync::test]
uses the production runtime, while #[lab_test] uses deterministic lab
runtime seed matrices.