pub struct Console { /* private fields */ }Expand description
Console for rendering styled output with terminal detection.
Implementations
Sourceimpl Console
impl Console
Sourcepub fn with_writer<W: Write + Send + 'static>(writer: W) -> Self
pub fn with_writer<W: Write + Send + 'static>(writer: W) -> Self
Create a console that writes to the provided writer with auto-detected capabilities.
Sourcepub fn with_caps<W: Write + Send + 'static>(
writer: W,
caps: Capabilities,
color_mode: ColorMode,
) -> Self
pub fn with_caps<W: Write + Send + 'static>( writer: W, caps: Capabilities, color_mode: ColorMode, ) -> Self
Create a console with explicit capabilities and color mode.
Sourcepub fn capabilities(&self) -> &Capabilities
pub fn capabilities(&self) -> &Capabilities
Returns the detected terminal capabilities.
Sourcepub fn color_mode(&self) -> ColorMode
pub fn color_mode(&self) -> ColorMode
Returns the current color mode.
Sourcepub fn set_color_mode(&mut self, mode: ColorMode)
pub fn set_color_mode(&mut self, mode: ColorMode)
Set the color mode for subsequent renders.
Sourcepub fn print(&self, content: &dyn Render) -> Result<()>
pub fn print(&self, content: &dyn Render) -> Result<()>
Render content without a trailing newline.
Sourcepub fn println(&self, content: &dyn Render) -> Result<()>
pub fn println(&self, content: &dyn Render) -> Result<()>
Render content with a trailing newline.
Sourcepub fn cursor_hide(&self) -> Result<()>
pub fn cursor_hide(&self) -> Result<()>
Hide the cursor (no-op if ANSI output is disabled).
Sourcepub fn cursor_show(&self) -> Result<()>
pub fn cursor_show(&self) -> Result<()>
Show the cursor (no-op if ANSI output is disabled).