NameLeaseError

Enum NameLeaseError 

pub enum NameLeaseError {
    AlreadyResolved,
    NameTaken {
        name: String,
        current_holder: TaskId,
    },
    NotFound {
        name: String,
    },
    WaitBudgetExceeded {
        name: String,
    },
    PermissionDenied {
        name: String,
    },
}
Error type for name lease operations.

Variants



AlreadyResolved

The lease has already been released or aborted.



NameTaken

The name is already registered by another task.

Fields

name: String

The name that was requested.

current_holder: TaskId

The task currently holding the name.



NotFound

The name was not found in the registry.

Fields

name: String

The name that was looked up.



WaitBudgetExceeded

A budgeted wait expired before the name became available.

Fields

name: String

The name that was waited on.



PermissionDenied

The permit does not belong to the pending entry’s holder/region.

Fields

name: String

The name that was denied.