PooledConnectionMeta

Struct PooledConnectionMeta 

pub struct PooledConnectionMeta {
    pub id: u64,
    pub state: PooledConnectionState,
    pub created_at: Time,
    pub last_used: Time,
    pub requests_served: u64,
    pub http_version: u8,
}
Metadata for a pooled connection.

Fields

id: u64

Unique identifier for this connection.

state: PooledConnectionState

Connection state.

created_at: Time

When the connection was created.

last_used: Time

When the connection was last used.

requests_served: u64

Number of requests served by this connection.

http_version: u8

HTTP version (1 for HTTP/1.x, 2 for HTTP/2).

Implementations

Source

impl PooledConnectionMeta

pub fn new(id: u64, now: Time, http_version: u8) -> Self

Creates new connection metadata.

pub fn mark_idle(&mut self, now: Time)

Marks the connection as idle.

pub fn mark_connected(&mut self, now: Time) -> bool

Marks the connection as connected only if it is still connecting.

Returns true when the transition was applied.

pub fn mark_in_use(&mut self)

Marks the connection as in use.

pub fn release(&mut self, now: Time) -> bool

Returns the connection to idle only if it is currently checked out.

Returns true when the transition was applied.

pub fn mark_unhealthy(&mut self)

Marks the connection as unhealthy.

pub fn is_expired(&self, now: Time, idle_timeout: Duration) -> bool

Returns true if this connection has been idle longer than the timeout.