pub fn test<F, R>(seed: u64, f: F) -> Rwhere
F: FnOnce(&mut LabRuntime) -> R,Expand description
Convenience function for running a test with the lab runtime.
pub fn test<F, R>(seed: u64, f: F) -> Rwhere
F: FnOnce(&mut LabRuntime) -> R,Convenience function for running a test with the lab runtime.