join

Macro join 

macro_rules! join {
    ($($future:expr),+ $(,)?) => { ... };
}
Macro for joining multiple futures (placeholder).

In the full implementation, this expands to spawn + join operations. Once the scheduler loop is implemented, this will spawn tasks and wait for all of them to complete.

Example (API shape)

let (r1, r2, r3) = join!(
    async { compute_a().await },
    async { compute_b().await },
    async { compute_c().await },
);