pub enum RwLockError {
Poisoned,
Cancelled,
PolledAfterCompletion,
}Expand description
Error returned when acquiring a read or write lock fails.
Variants
Poisoned
The lock was poisoned (a panic occurred while holding a guard).
Cancelled
Cancelled while waiting.
PolledAfterCompletion
The future was polled again after it already returned Ready.