pub struct OwnedRwLockWriteGuard<T> { /* private fields */ }Expand description
Owned write guard that can be moved between tasks.
Implementations
Sourceimpl<T> OwnedRwLockWriteGuard<T>
impl<T> OwnedRwLockWriteGuard<T>
Sourcepub fn write(lock: Arc<RwLock<T>>, cx: &Cx) -> OwnedWriteFuture<'_, T>
pub fn write(lock: Arc<RwLock<T>>, cx: &Cx) -> OwnedWriteFuture<'_, T>
Acquires an owned write guard from an Arc<RwLock<T>>.
Sourcepub fn try_write(lock: Arc<RwLock<T>>) -> Result<Self, TryWriteError>
pub fn try_write(lock: Arc<RwLock<T>>) -> Result<Self, TryWriteError>
Tries to acquire an owned write guard without waiting.
Sourcepub fn with_write<F, R>(&mut self, f: F) -> R
pub fn with_write<F, R>(&mut self, f: F) -> R
Executes a closure with exclusive access to the data.