pub enum LogicalTime {
Lamport(LamportTime),
Vector(VectorClock),
Hybrid(HybridTime),
}Expand description
Logical time values for heterogeneous clock types.
Variants
Lamport(LamportTime)
Lamport clock time.
Vector(VectorClock)
Vector clock time.
Hybrid(HybridTime)
Hybrid clock time.
Implementations
Sourceimpl LogicalTime
impl LogicalTime
Sourcepub const fn kind(&self) -> LogicalClockKind
pub const fn kind(&self) -> LogicalClockKind
Returns the logical clock kind for this time value.
Sourcepub fn causal_order(&self, other: &Self) -> CausalOrder
pub fn causal_order(&self, other: &Self) -> CausalOrder
Compares two logical times for causal ordering.
Returns the causal relationship between self and other.
For Lamport/Hybrid clocks this is derived from total/partial order;
for vector clocks this uses the vector clock causal order directly.
Returns CausalOrder::Concurrent if the clock types differ.