StatusCode

Struct StatusCode 

pub struct StatusCode(/* private fields */);
HTTP status code.

Implementations

Source

impl StatusCode

pub const CONTINUE: Self

100 Continue

pub const SWITCHING_PROTOCOLS: Self

101 Switching Protocols

pub const OK: Self

200 OK

pub const CREATED: Self

201 Created

pub const ACCEPTED: Self

202 Accepted

pub const NO_CONTENT: Self

204 No Content

pub const PARTIAL_CONTENT: Self

206 Partial Content

pub const MOVED_PERMANENTLY: Self

301 Moved Permanently

pub const FOUND: Self

302 Found

pub const SEE_OTHER: Self

303 See Other

pub const NOT_MODIFIED: Self

304 Not Modified

pub const TEMPORARY_REDIRECT: Self

307 Temporary Redirect

pub const PERMANENT_REDIRECT: Self

308 Permanent Redirect

pub const BAD_REQUEST: Self

400 Bad Request

pub const UNAUTHORIZED: Self

401 Unauthorized

pub const FORBIDDEN: Self

403 Forbidden

pub const NOT_FOUND: Self

404 Not Found

pub const METHOD_NOT_ALLOWED: Self

405 Method Not Allowed

pub const REQUEST_TIMEOUT: Self

408 Request Timeout

pub const CONFLICT: Self

409 Conflict

pub const PAYLOAD_TOO_LARGE: Self

413 Payload Too Large

pub const UNSUPPORTED_MEDIA_TYPE: Self

415 Unsupported Media Type

pub const RANGE_NOT_SATISFIABLE: Self

416 Range Not Satisfiable

pub const UNPROCESSABLE_ENTITY: Self

422 Unprocessable Entity

pub const TOO_MANY_REQUESTS: Self

429 Too Many Requests

pub const CLIENT_CLOSED_REQUEST: Self

499 Client Closed Request

pub const INTERNAL_SERVER_ERROR: Self

500 Internal Server Error

pub const NOT_IMPLEMENTED: Self

501 Not Implemented

pub const BAD_GATEWAY: Self

502 Bad Gateway

pub const SERVICE_UNAVAILABLE: Self

503 Service Unavailable

pub const GATEWAY_TIMEOUT: Self

504 Gateway Timeout

pub const fn from_u16(code: u16) -> Self

Create a status code from a raw value.

pub const fn as_u16(self) -> u16

Return the numeric status code.

pub const fn is_success(self) -> bool

Returns true if the status code indicates success (2xx).

pub const fn is_client_error(self) -> bool

Returns true if the status code indicates a client error (4xx).

pub const fn is_server_error(self) -> bool

Returns true if the status code indicates a server error (5xx).