Module http

Module http 

HTTP protocol support for Asupersync.

This module provides HTTP/1.1 and HTTP/2 protocol implementations with cancel-safe body handling and connection pooling.

Body Types

The body module provides the Body trait and common implementations for streaming HTTP message bodies.

HTTP/2

The h2 module provides HTTP/2 protocol support including frame parsing, HPACK compression, and flow control.

Connection Pooling

The pool module provides connection pool management for HTTP clients, enabling connection reuse for improved performance.

Re-exports

pub use body::Body;
pub use body::Empty;
pub use body::Frame;
pub use body::Full;
pub use body::HeaderMap;
pub use body::HeaderName;
pub use body::HeaderValue;
pub use body::SizeHint;
pub use h3_native::H3ConnectionConfig;
pub use h3_native::H3ConnectionState;
pub use h3_native::H3ControlState;
pub use h3_native::H3Frame as NativeH3Frame;
pub use h3_native::H3NativeError;
pub use h3_native::H3PseudoHeaders;
pub use h3_native::H3QpackMode;
pub use h3_native::H3RequestHead;
pub use h3_native::H3RequestStreamState;
pub use h3_native::H3ResponseHead;
pub use h3_native::H3Settings as NativeH3Settings;
pub use h3_native::H3UniStreamType;
pub use h3_native::QpackFieldPlan;
pub use h3_native::UnknownSetting;
pub use h3_native::qpack_decode_field_section;
pub use h3_native::qpack_encode_field_section;
pub use h3_native::qpack_encode_request_field_section;
pub use h3_native::qpack_encode_response_field_section;
pub use h3_native::qpack_plan_to_header_fields;
pub use h3_native::qpack_static_plan_for_request;
pub use h3_native::qpack_static_plan_for_response;
pub use h3_native::validate_request_pseudo_headers;
pub use h3_native::validate_response_pseudo_headers;
pub use pool::Pool;
pub use pool::PoolConfig;
pub use pool::PoolKey;
pub use pool::PoolStats;
pub use pool::PooledConnectionMeta;
pub use pool::PooledConnectionState;

Modules

body
HTTP body abstraction for streaming request and response bodies.
compress
HTTP body compression and content-encoding negotiation.
h1
HTTP/1.1 protocol implementation.
h2
HTTP/2 protocol implementation.
h3_native
Native HTTP/3 protocol primitives over QUIC streams.
pool
HTTP connection pooling.