pub struct Decoder { /* private fields */ }Expand description
HPACK decoder for decoding headers.
Implementations
Sourceimpl Decoder
impl Decoder
Sourcepub fn with_max_size(max_size: usize) -> Self
pub fn with_max_size(max_size: usize) -> Self
Create a decoder with specified max table size.
Sourcepub fn set_max_header_list_size(&mut self, size: usize)
pub fn set_max_header_list_size(&mut self, size: usize)
Set the maximum header list size.
Sourcepub fn set_allowed_table_size(&mut self, size: usize)
pub fn set_allowed_table_size(&mut self, size: usize)
Set the allowed table size (from SETTINGS frame). This limits what the peer can request via dynamic table size updates.
Sourcepub fn decode(&mut self, src: &mut Bytes) -> Result<Vec<Header>, H2Error>
pub fn decode(&mut self, src: &mut Bytes) -> Result<Vec<Header>, H2Error>
Decode headers from a buffer.
Per RFC 7541 4.2, dynamic table size updates are only permitted at the beginning of the header block (before the first header field representation). Any size update after a header field representation is a COMPRESSION_ERROR.