Distributed tracing infrastructure.
This module provides:
- Trace identifiers and context (
id,context,span,collector): W3C-compatible trace IDs, symbol-level span recording, and in-process collection. - Vector clocks (
vclock): Causal ordering for distributed events. Events are partially ordered: concurrent events remain unordered. - Convergent state lattice (
lattice): Join-semilattice for obligation and lease state that converges across replicas via CRDT-style merge. - CRDTs (
crdt): Standard convergent replicated data types — GCounter, PNCounter, LWWRegister, ORSet, MVRegister.
Re-exports
pub use collector::SymbolTraceCollector;pub use collector::TraceRecord;pub use collector::TraceSummary;pub use context::RegionTag;pub use context::SymbolTraceContext;pub use context::TraceFlags;pub use crdt::GCounter;pub use crdt::LWWRegister;pub use crdt::MVRegister;pub use crdt::Merge;pub use crdt::ORSet;pub use crdt::PNCounter;pub use id::SymbolSpanId;pub use id::TraceId;pub use lattice::LatticeState;pub use lattice::LeaseLatticeState;pub use lattice::ObligationEntry;pub use lattice::ObligationLattice;pub use sheaf::ConsistencyReport;pub use sheaf::ConstraintViolation;pub use sheaf::NodeSnapshot;pub use sheaf::PhantomState;pub use sheaf::SagaConsistencyChecker;pub use sheaf::SagaConstraint;pub use span::SymbolSpan;pub use span::SymbolSpanKind;pub use span::SymbolSpanStatus;pub use vclock::CausalEvent;pub use vclock::CausalOrder;pub use vclock::CausalTracker;pub use vclock::HybridClock;pub use vclock::HybridTime;pub use vclock::LamportClock;pub use vclock::LamportTime;pub use vclock::LogicalClock;pub use vclock::LogicalClockHandle;pub use vclock::LogicalClockKind;pub use vclock::LogicalClockMode;pub use vclock::LogicalTime;pub use vclock::VectorClock;pub use vclock::VectorClockHandle;
Modules
- collector
- In-process collector for symbol trace spans.
- context
- Trace context that propagates with symbols.
- crdt
- Convergent Replicated Data Types (CRDTs) for distributed coordination.
- id
- Trace identifiers for symbol-based distributed tracing.
- lattice
- Convergent state lattice for distributed obligation and lease state.
- sheaf
- Sheaf-theoretic consistency checks for distributed sagas.
- span
- Span types representing symbol operations.
- vclock
- Vector clocks for causal ordering of distributed trace events.