pub struct CheckpointState {
pub last_checkpoint: Option<Time>,
pub last_message: Option<String>,
pub checkpoint_count: u64,
}Expand description
State for tracking checkpoint progress.
This struct tracks progress reporting checkpoints, which are distinct from cancellation checkpoints. Progress checkpoints indicate that a task is making forward progress and are useful for:
- Detecting stuck/stalled tasks
- Work-stealing scheduler decisions
- Observability and debugging
Fields
last_checkpoint: Option<Time>The runtime time of the last checkpoint.
last_message: Option<String>The message from the last checkpoint_with() call.
checkpoint_count: u64The total number of checkpoints recorded.
Implementations
Sourceimpl CheckpointState
impl CheckpointState
Sourcepub fn record_with_message(&mut self, message: String)
pub fn record_with_message(&mut self, message: String)
Records a checkpoint with a message.
Sourcepub fn record_with_message_at(&mut self, message: String, at: Time)
pub fn record_with_message_at(&mut self, message: String, at: Time)
Records a checkpoint with a message at an explicit runtime time.